"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var liveSyncServiceBaseLib = require("./livesync-service-base");
var helpers = require("../../common/helpers");
var net = require("net");
var currentPageReloadId = 0;
var IOSLiveSyncService = (function (_super) {
    __extends(IOSLiveSyncService, _super);
    function IOSLiveSyncService(_device, $iOSSocketRequestExecutor, $iOSNotification, $iOSEmulatorServices, $injector, $logger) {
        _super.call(this, _device);
        this.$iOSSocketRequestExecutor = $iOSSocketRequestExecutor;
        this.$iOSNotification = $iOSNotification;
        this.$iOSEmulatorServices = $iOSEmulatorServices;
        this.$injector = $injector;
        this.$logger = $logger;
    }
    IOSLiveSyncService.prototype.removeFiles = function (appIdentifier, localToDevicePaths) {
        var _this = this;
        return (function () {
            _.each(localToDevicePaths, function (localToDevicePathData) { return _this.device.fileSystem.deleteFile(localToDevicePathData.getDevicePath(), appIdentifier); });
        }).future()();
    };
    IOSLiveSyncService.prototype.restartApplication = function (deviceAppData) {
        var projectData = this.$injector.resolve("projectData");
        return this.device.applicationManager.restartApplication(deviceAppData.appIdentifier, projectData.projectName);
    };
    IOSLiveSyncService.prototype.reloadPage = function (deviceAppData) {
        var _this = this;
        return (function () {
            var timeout = 9000;
            if (_this.device.isEmulator) {
                helpers.connectEventually(function () { return net.connect(IOSLiveSyncService.BACKEND_PORT); }, function (socket) { return _this.sendPageReloadMessage(socket); });
                _this.$iOSEmulatorServices.postDarwinNotification(_this.$iOSNotification.attachRequest).wait();
            }
            else {
                _this.$iOSSocketRequestExecutor.executeAttachRequest(_this.device, timeout).wait();
                var socket = _this.device.connectToPort(IOSLiveSyncService.BACKEND_PORT);
                _this.sendPageReloadMessage(socket);
            }
        }).future()();
    };
    IOSLiveSyncService.prototype.sendPageReloadMessage = function (socket) {
        var _this = this;
        try {
            this.sendPageReloadMessageCore(socket);
            socket.once("data", function (data) {
                _this.$logger.trace("Socket sent data: " + data.toString());
                socket.destroy();
            });
        }
        catch (err) {
            this.$logger.trace("Error while sending page reload:", err);
            socket.destroy();
        }
    };
    IOSLiveSyncService.prototype.sendPageReloadMessageCore = function (socket) {
        var message = "{ \"method\":\"Page.reload\",\"params\":{\"ignoreCache\":false},\"id\":" + ++currentPageReloadId + " }";
        var length = Buffer.byteLength(message, "utf16le");
        var payload = new Buffer(length + 4);
        payload.writeInt32BE(length, 0);
        payload.write(message, 4, length, "utf16le");
        socket.write(payload);
    };
    IOSLiveSyncService.BACKEND_PORT = 18181;
    return IOSLiveSyncService;
})(liveSyncServiceBaseLib.LiveSyncServiceBase);
$injector.register("iosLiveSyncServiceLocator", { factory: IOSLiveSyncService });
